@@ -56,6 +56,8 @@ import { vitals } from './vitals';
 import { translation } from './translation';
 import { upcomingVaccinations } from './upcomingVaccinations';
 import { telegramRoutes } from './telegram/telegramRoutes';
+import { tasks } from './task/tasks';
+import { notifications } from './notifications';
 
 export const apiv1 = express.Router();
 const patientDataRoutes = express.Router();
@@ -146,6 +148,8 @@ patientDataRoutes.use('/surveyResponse', surveyResponse);
 patientDataRoutes.use('/surveyResponseAnswer', surveyResponseAnswer);
 patientDataRoutes.use('/triage', triage);
 patientDataRoutes.use('/vitals', vitals);
+patientDataRoutes.use('/tasks', tasks);
+patientDataRoutes.use('/notifications', notifications);
 
 // reference data endpoints
 referenceDataRoutes.use('/asset', asset);
