@@ -2,12 +2,13 @@ import asyncHandler from 'express-async-handler';
 import { Op, QueryTypes, Sequelize } from 'sequelize';
 
 import { HIDDEN_VISIBILITY_STATUSES } from '@tamanu/constants/importable';
-import { renameObjectKeys } from '@tamanu/shared/utils/renameObjectKeys';
+import { renameObjectKeys } from '@tamanu/utils/renameObjectKeys';
 import {
   permissionCheckingRouter,
   runPaginatedQuery,
   simpleGetList,
 } from '@tamanu/shared/utils/crudHelpers';
+import { ENCOUNTER_TYPE_VALUES, ENCOUNTER_TYPE_LABELS } from '@tamanu/constants';
 
 import { patientSecondaryIdRoutes } from './patientSecondaryId';
 import { patientDeath } from './patientDeath';
@@ -32,6 +33,13 @@ patientRelations.get(
 
     const ENCOUNTER_SORT_KEYS = {
       startDate: 'start_date',
+      encounterType: `
+        CASE
+          ${ENCOUNTER_TYPE_VALUES.map(
+            value => `WHEN encounter_type = '${value}' THEN '${ENCOUNTER_TYPE_LABELS[value]}'`,
+          ).join(' ')}
+        END
+      `,
       endDate: 'end_date',
       facilityName: 'facility_name',
       locationGroupName: 'location_group_name',
@@ -168,7 +176,7 @@ patientRelations.get(
         count: 0,
       });
     }
-    
+
     const patientReferrals = await models.Referral.findAll({
       include: [
         {
@@ -321,6 +329,7 @@ patientRelations.get(
   '/:id/labTestResults',
   asyncHandler(async (req, res) => {
     req.checkPermission('list', 'LabTest');
+    const canListSensitive = req.ability.can('list', 'SensitiveLabRequest');
     const {
       db,
       models: { LabTest },
@@ -376,6 +385,10 @@ patientRelations.get(
   AND lab_requests.status = :status
   AND lab_requests.sample_time IS NOT NULL
   AND lab_requests.deleted_at IS NULL
+  AND CASE WHEN :canListSensitive IS TRUE
+    THEN TRUE
+    ELSE lab_test_types.is_sensitive IS FALSE
+    END
   ${categoryId ? 'AND lab_requests.lab_test_category_id = :categoryId' : ''}
   ${
     panelId
@@ -393,7 +406,7 @@ patientRelations.get(
   ORDER BY
     test_category`,
       {
-        replacements: { patientId: params.id, status, categoryId, panelId },
+        replacements: { patientId: params.id, status, categoryId, panelId, canListSensitive },
         model: LabTest,
         type: QueryTypes.SELECT,
         mapToModel: true,
